@@ -1,5 +1,6 @@
 from __future__ import annotations
 from functools import lru_cache
+import json
 import typing as t
 import uuid
 
@@ -12,7 +13,10 @@ from piccolo.columns.column_types import (
     Numeric,
     Varchar,
     Secret,
+    JSON,
+    JSONB,
 )
+from piccolo.utils.encoding import load_json
 from piccolo.table import Table
 import pydantic
 
@@ -22,6 +26,15 @@ class Config(pydantic.BaseConfig):
     arbitrary_types_allowed = True
 
 
+def pydantic_json_validator(cls, value):
+    try:
+        load_json(value)
+    except json.JSONDecodeError:
+        raise ValueError("Unable to parse the JSON.")
+    else:
+        return value
+
+
 @lru_cache()
 def create_pydantic_model(
     table: t.Type[Table],
@@ -29,6 +42,7 @@ def create_pydantic_model(
     include_readable: bool = False,
     all_optional: bool = False,
     model_name: t.Optional[str] = None,
+    deserialize_json: bool = False,
 ) -> t.Type[pydantic.BaseModel]:
     """
     Create a Pydantic model representing a table.
@@ -49,11 +63,16 @@ def create_pydantic_model(
         By default, the classname of the Piccolo ``Table`` will be used, but
         you can override it if you want multiple Pydantic models based off the
         same Piccolo table.
+    :param deserialize_json:
+        By default, the values of any Piccolo JSON or JSONB columns are
+        returned as strings. By setting this parameter to True, they will be
+        returned as objects.
     :returns:
         A Pydantic model.
 
     """
     columns: t.Dict[str, t.Any] = {}
+    validators: t.Dict[str, classmethod] = {}
     piccolo_columns = (
         table._meta.columns
         if include_default_columns
@@ -76,6 +95,14 @@ def create_pydantic_model(
             value_type = pydantic.constr(max_length=column.length)
         elif isinstance(column, Array):
             value_type = t.List[column.base_column.value_type]  # type: ignore
+        elif isinstance(column, (JSON, JSONB)):
+            if deserialize_json:
+                value_type = pydantic.Json
+            else:
+                value_type = column.value_type
+                validators[f"{column_name}_is_json"] = pydantic.validator(
+                    column_name, allow_reuse=True
+                )(pydantic_json_validator)
         else:
             value_type = column.value_type
 
@@ -118,5 +145,8 @@ def create_pydantic_model(
         schema_extra = {"help_text": table._meta.help_text}
 
     return pydantic.create_model(
-        model_name, __config__=CustomConfig, **columns
+        model_name,
+        __config__=CustomConfig,
+        __validators__=validators,
+        **columns,
     )
